[PATCH v2 3/3] drm/amd: Skip RLC suspend for s0ix on PSP 13.0.4 and 13.0.11

Mario Limonciello mario.limonciello at amd.com
Tue May 16 23:34:20 UTC 2023


RLC suspend in s0ix is unncessary as the SMU and IMU jointly
manages graphics power state.

Suggested-by: Alexander Deucher <Alexander.Deucher at amd.com>
Signed-off-by: Mario Limonciello <mario.limonciello at amd.com>
---
v1->v2:
 * Skip RLC all the time instead of adding safety to it
---
 drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c b/drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c
index 4dea79a0c5b5..f8510ce1c4f7 100644
--- a/drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c
+++ b/drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c
@@ -1549,9 +1549,9 @@ static int smu_disable_dpms(struct smu_context *smu)
 
 	/*
 	 * For SMU 13.0.4/11, PMFW will handle the features disablement properly
 	 * for gpu reset case. Driver involvement is unnecessary.
 	 */
-	if (amdgpu_in_reset(adev)) {
+	if (amdgpu_in_reset(adev) || adev->in_s0ix) {
 		switch (adev->ip_versions[MP1_HWIP][0]) {
 		case IP_VERSION(13, 0, 4):
 		case IP_VERSION(13, 0, 11):
@@ -1549,9 +1549,9 @@ static int smu_disable_dpms(struct smu_context *smu)
 	/*
 	 * For SMU 13.0.4/11, PMFW will handle the features disablement properly
-	 * for gpu reset case. Driver involvement is unnecessary.
+	 * for gpu reset and s0ix case. Driver involvement is unnecessary.
 	 */
-- 
2.34.1



More information about the amd-gfx mailing list